<?php

/**
 * @file
 * Simpletest case for node_example module.
 *
 * Verify example module functionality.
 */

/**
 * Functionality tests for reservations module.
 * General setup and functions all reservations tests should inherit.
 */
class ReservationsTestCase extends DrupalWebTestCase {


  public $admin_user;

  function setUp() {
    // Enable the module.
    parent::setUp(
        'node',
        'devel',
        //'content',
        //'fieldgroup',
        //'optionwidgets',
        //'text',
        //'number',
        //'jquery_ui',
        //'date_api',
        //'date',
        //'date_timezone',
        //'date_popup',
        //'text',
        //'views',
        'reservations'
        //'reservations_staff'

        );

    $perms = user_permission_get_modules();
    $this->verbose('perms: ' . var_export($perms, TRUE));
    // Create admin user. 
    $this->admin_user = $this->drupalCreateUser(array(
      'administer nodes', // Required to set revision checkbox
      'bypass node access',
      'administer content types',
      'access administration pages',
      'administer site configuration',
      'view revisions',
      'revert revisions',
      'access devel information',
      'administer Reservations',
      'manage reservations'
    ));
    // Login the admin user.
    $this->drupalLogin($this->admin_user);

    $settings = array (
      'reservations_default_reservation_status' => '2',
      'reservations_max_days_advance_reservation' => '0',
      'reservations_saturday_is_weekend' => '1',
      'reservations_sunday_is_weekend' => '1',
      'reservations_hours_monday' => '09:00-17:00',
      'reservations_hours_tuesday' => '09:00-17:00',
      'reservations_hours_wednesday' => '09:00-17:00',
      'reservations_hours_thursday' => '09:00-17:00',
      'reservations_hours_friday' => '09:00-17:00',
      'reservations_hours_saturday' => '09:00-17:00',
      'reservations_hours_sunday' => '09:00-17:00',
      'reservations_hours_admin' => '07:00-22:00',
      'reservations_closed_dates' => '12-25',
      'reservations_lock'    => FALSE,
    );

    $this->reservationsCreateConfig($settings);

    $settings = array (
      'date_default_timezone' => 'America/Los_Angeles',
      );
    $this->drupalPost('admin/config/regional/settings' , $settings, t('Save configuration'));
    $this->assertText(t("The configuration options have been saved."));

    $settings = array ( 
      'instance[widget][settings][input_format]' => 'Y-m-d H:i:s',
    );
    $this->drupalPost('admin/structure/types/manage/reservations-reservation/fields/field_reservations_date', $settings, t('Save settings'));
    $this->assertText(t("Saved Reservation configuration"));
  }


  function reservationsCreateContentType($settings,$reservations_type,$reservations_settings=NULL) {
    // Create resource content type
    // Disable the rating for this content type: 0 for Disabled, 1 for Enabled.
    if (node_type_get_type($settings['type'])) {
      return $settings['type'];
    }
    $content_type = $this->drupalCreateContentType($settings);
    $this->verbose('settings ' . var_export($content_type, TRUE));
    $type = $content_type->type;
    $settings = array(
        'reservations_type_setting' => $reservations_type,
        'reservations_max_hours_per_reservation' => 5
    );
    if($reservations_settings) {
      $settings = $settings + $reservations_settings;
    }
    $this->drupalPost('admin/structure/types/manage/' . $type, $settings, t('Save content type'));
    $this->assertResponse(200);
    $this->assertRaw(' has been updated.', t('Settings modified successfully for content type.'));
    return $type;
  }

  function reservationsCreateNode($type,$settings,$pass=TRUE) {
    $this->verbose('Creating node: ' . var_export($settings, TRUE));
    $this->drupalPost('node/add/' . $type, $settings, t('Save'));
    $node = entity_load('node',FALSE,array('title' => $settings['title']));
    $this->verbose('Node created: ' . var_export($node, TRUE));
    return array_shift($node);
  }

  function reservationsUpdateNode($nid,$settings,$pass=TRUE) {
    $this->drupalPost("node/$nid/edit", $settings, t('Save'));
    $node = node_load($nid);
    return $node;
  }

  function reservationsCreateConfig($settings) {
    $this->drupalPost('admin/config/system/reservations' , $settings, t('Save configuration'));
    $this->assertText(t("The configuration options have been saved."));
  }

  function reservationsCreateItem($reservations_type, $type = NULL, $reservations_settings = array()) {

    $type = $type ? $type : $reservations_type;
    $settings = array (
        'type'  => $type,
        );
    $type = $this->reservationsCreateContentType($settings, $reservations_type, $reservations_settings);
    // Create resource item
    $edit = array(
      'title' => $this->randomName()
    );

    $item = $this->reservationsCreateNode($type, $edit);
    $this->assertText(t("@title has been created", array('@title' => $edit['title'])));
    return $item;
  }
}

